@@ -19,6 +19,9 @@
 package org.apache.catalina.ant;
 
 
+import java.io.UnsupportedEncodingException;
+import java.net.URLEncoder;
+
 import org.apache.tools.ant.BuildException;
 
 
@@ -27,7 +30,7 @@ import org.apache.tools.ant.BuildException;
  * the Tomcat manager application.
  *
  * @author Craig R. McClanahan
- * @version $Id: ResourcesTask.java 939336 2010-04-29 15:00:41Z kkolinko $
+ * @version $Id: ResourcesTask.java 1080226 2011-03-10 13:57:55Z markt $
  * @since 4.1
  */
 public class ResourcesTask extends AbstractCatalinaTask {
@@ -63,7 +66,13 @@ public class ResourcesTask extends AbstractCatalinaTask {
 
         super.execute();
         if (type != null) {
-            execute("/resources?type=" + type);
+            try {
+                execute("/resources?type=" +
+                        URLEncoder.encode(type, getCharset()));
+            } catch (UnsupportedEncodingException e) {
+                throw new BuildException
+                    ("Invalid 'charset' attribute: " + getCharset());
+            }
         } else {
             execute("/resources");
         }
