@@ -68,7 +68,7 @@ import org.apache.tomcat.util.http.fileupload.FileItem;
 * @author Bip Thelin
 * @author Malcolm Edgar
 * @author Glenn L. Nielsen
-* @version $Id: HTMLManagerServlet.java 1124220 2011-05-18 12:35:40Z markt $
+* @version $Id: HTMLManagerServlet.java 1428973 2013-01-04 16:53:02Z kkolinko $
 * @see ManagerServlet
 */
 
@@ -406,7 +406,7 @@ public final class HTMLManagerServlet extends ManagerServlet {
                 }
                 
                 args = new Object[7];
-                args[0] = URL_ENCODER.encode(displayPath);
+                args[0] = URL_ENCODER.encode(contextPath + "/");
                 args[1] = RequestUtil.filter(displayPath);
                 if (context.getDisplayName() == null) {
                     args[2] = "&nbsp;";
@@ -676,7 +676,7 @@ public final class HTMLManagerServlet extends ManagerServlet {
      * @see javax.servlet.Servlet#getServletInfo()
      */
     public String getServletInfo() {
-        return "HTMLManagerServlet, Copyright (c) 1999-2011, The Apache Software Foundation";
+        return "HTMLManagerServlet, Copyright (c) 1999-2013, The Apache Software Foundation";
     }   
     
     /**
