@@ -64,7 +64,7 @@ import org.xml.sax.SAXParseException;
  *
  * @author Craig R. McClanahan
  * @author Jean-Francois Arcand
- * @version $Id: ContextConfig.java 964731 2010-07-16 10:12:01Z markt $
+ * @version $Id: ContextConfig.java 1228244 2012-01-06 16:09:08Z kkolinko $
  */
 
 public class ContextConfig
@@ -964,14 +964,14 @@ public class ContextConfig
                 docBase = "ROOT";
             } else {
                 if (path.startsWith("/")) {
-                    docBase = path.substring(1);
+                    docBase = path.substring(1).replace('/','#');
                 } else {
-                    docBase = path;
+                    docBase = path.replace('/','#');
                 }
             }
 
             File file = null;
-            if (docBase.toLowerCase().endsWith(".war")) {
+            if (originalDocBase.toLowerCase().endsWith(".war")) {
                 file = new File(System.getProperty("java.io.tmpdir"),
                         deploymentCount++ + "-" + docBase + ".war");
             } else {
